<html>
<head>
	<title>Rubric</title>
	<link href='[% url_for('css') %]' rel='stylesheet' type='text/css' />
</head>
<body>
	<h1>
		rubric
	</h1>

	[% PROCESS "toolbar.html" %]
	<h2>log in!</h2>
	<div class='must_login'>
		You must log in to use this feature.
	</div>
	</body>
</html>
